<?php
namespace FlizVideoGenerator\Admin;

class BulkGenerator {
    private $post_list;

    public function __construct() {
        add_action('admin_enqueue_scripts', [$this, 'enqueue_scripts']);
        add_action('wp_ajax_fliz_bulk_generate_videos', [$this, 'handle_bulk_generation']);
        
        if (!class_exists('WP_List_Table')) {
            require_once(ABSPATH . 'wp-admin/includes/class-wp-list-table.php');
        }
    }

    public function init() {
        $this->post_list = new PostList();
    }

    public function handle_bulk_generation() {
        check_ajax_referer('fliz_bulk_generator_nonce', 'nonce');

        if (!current_user_can('manage_options')) {
            wp_send_json_error(
                /* translators: Error message when user doesn't have required permissions */
                __('Permission denied', 'fliz-video-generator')
            );
        }

        $post_ids = isset($_POST['posts']) ? array_map('intval', $_POST['posts']) : [];
        
        // Validation et nettoyage de video_type
        $video_type = isset($_POST['video_type']) ? 
            sanitize_text_field(wp_unslash($_POST['video_type'])) : 
            'article';  // valeur par défaut
            
        // Validation et nettoyage de video_format
        $video_format = isset($_POST['video_format']) ? 
            sanitize_text_field(wp_unslash($_POST['video_format'])) : 
            'size_16_9';  // valeur par défaut

        if (empty($post_ids)) {
            wp_send_json_error(
                /* translators: Error message when no posts are selected */
                __('No posts selected', 'fliz-video-generator')
            );
        }

        $api = new \FlizVideoGenerator\Api\FlizApi();
        $errors = [];

        foreach ($post_ids as $post_id) {
            $post = get_post($post_id);
            if (!$post) continue;

            $input = [
                'post_id' => $post_id,
                'name' => $post->post_title,
                'description' => wp_strip_all_tags($post->post_content),
                'site_url' => get_permalink($post_id),
                'site_name' => get_bloginfo('name'),
                'lang' => substr(get_locale(), 0, 2),
                'format' => $video_format,
                'category' => $video_type
            ];

            $result = $api->create_video($input);

            if (is_wp_error($result)) {
                $errors[] = sprintf(
                    /* translators: %1$s: post title, %2$s: error message */
                    __('Error for post "%1$s": %2$s', 'fliz-video-generator'),
                    $post->post_title,
                    $result->get_error_message()
                );
                continue;
            }

            if (!isset($result['fliz_video_create']['video_id'])) {
                $errors[] = sprintf(
                    /* translators: %s: post title */
                    __('Error for post "%s": Missing video ID', 'fliz-video-generator'),
                    $post->post_title
                );
                continue;
            }

            $video_id = $result['fliz_video_create']['video_id'];
            update_post_meta($post_id, '_fliz_video_id', $video_id);

            // Ajouter le shortcode à la fin de l'article
            $content = $post->post_content;
            if (substr($content, -1) !== "\n") {
                $content .= "\n";
            }
            $content .= "\n[fliz_video id=\"" . $video_id . "\"]";

            wp_update_post([
                'ID' => $post_id,
                'post_content' => $content
            ]);
        }

        if (!empty($errors)) {
            wp_send_json_error(implode("\n", $errors));
        }

        wp_send_json_success(
            /* translators: Success message after videos are queued */
            __('Videos are being generated.', 'fliz-video-generator')
        );
    }

    public function enqueue_scripts($hook) {
        if (!isset($_GET['page']) || $_GET['page'] !== 'fliz-video-bulk') {
            return;
        }

        wp_enqueue_style(
            'fliz-bulk-generator',
            FLIZ_VIDEO_GENERATOR_URL . 'assets/css/bulk-generator.css',
            [],
            FLIZ_VIDEO_GENERATOR_VERSION
        );

        wp_enqueue_script(
            'fliz-bulk-generator',
            FLIZ_VIDEO_GENERATOR_URL . 'assets/js/bulk-generator.js',
            ['jquery'],
            FLIZ_VIDEO_GENERATOR_VERSION,
            true
        );

        wp_localize_script('fliz-bulk-generator', 'flizBulk', [
            'ajaxurl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('fliz_bulk_generator_nonce'),
            'selectPosts' => /* translators: Error message when no posts are selected */
                __('Please select at least one post', 'fliz-video-generator'),
            'confirmGeneration' => /* translators: Confirmation message before generating videos */
                __('Are you sure you want to generate videos for the selected posts?', 'fliz-video-generator'),
            'generating' => /* translators: Message shown while videos are being generated */
                __('Generating...', 'fliz-video-generator'),
            'success' => /* translators: Success message after videos are queued for generation */
                __('The videos are being created and will be available in a few minutes.', 'fliz-video-generator'),
            'error' => /* translators: Generic error message */
                __('Error during generation', 'fliz-video-generator')
        ]);
    }

    public function render_page() {
        $this->init();
        
        ?>
        <div class="wrap">
            <h1><?php echo esc_html__('Generate videos', 'fliz-video-generator'); ?></h1>
            
            <div class="notice notice-info">
                <p><?php echo esc_html__('Select the posts for which you want to generate videos.', 'fliz-video-generator'); ?></p>
            </div>

            <form id="posts-filter" method="get">
                <input type="hidden" name="page" value="<?php echo esc_attr('fliz-video-bulk'); ?>">
                <?php
                $this->post_list->prepare_items();
                $this->post_list->search_box(
                    esc_html__('Search', 'fliz-video-generator'), 
                    'post'
                );
                $this->post_list->display();
                ?>
            </form>
        </div>

        <!-- Modal de configuration -->
        <div id="fliz-generator-modal" class="fliz-modal" style="display: none;">
            <div class="fliz-modal-content">
                <h2><?php echo esc_html__('Generation settings', 'fliz-video-generator'); ?></h2>
                
                <div class="fliz-modal-body">
                    <p>
                        <label><?php echo esc_html__('Video type:', 'fliz-video-generator'); ?></label><br>
                        <select name="video_type" id="fliz-video-type">
                            <option value="article">
                                <?php echo esc_html__('Article', 'fliz-video-generator'); ?>
                            </option>
                            <option value="ad">
                                <?php echo esc_html__('Advertisement', 'fliz-video-generator'); ?>
                            </option>
                            <option value="product">
                                <?php echo esc_html__('Product', 'fliz-video-generator'); ?>
                            </option>
                        </select>
                    </p>

                    <p>
                        <label><?php echo esc_html__('Format:', 'fliz-video-generator'); ?></label><br>
                        <select name="video_format" id="fliz-video-format">
                            <option value="size_16_9">16:9</option>
                            <option value="size_9_16">9:16</option>
                            <option value="square">
                                <?php echo esc_html__('Square', 'fliz-video-generator'); ?>
                            </option>
                        </select>
                    </p>
                </div>

                <div class="fliz-modal-footer">
                    <button type="button" class="button button-secondary fliz-modal-close">
                        <?php echo esc_html__('Cancel', 'fliz-video-generator'); ?>
                    </button>
                    <button type="button" class="button button-primary" id="fliz-generate-videos">
                        <?php echo esc_html__('Generate', 'fliz-video-generator'); ?>
                    </button>
                </div>
            </div>
        </div>
        <?php
    }
} 