<?php
namespace FlizVideoGenerator\Admin;

class PostList extends \WP_List_Table {
    public function __construct() {
        parent::__construct([
            'singular' => 'post',
            'plural'   => 'posts',
            'ajax'     => false
        ]);
    }

    public function get_columns() {
        return [
            'cb' => '<input type="checkbox" />',
            'title' => esc_html__('Title', 'fliz-video-generator'),
            'author' => esc_html__('Author', 'fliz-video-generator'),
            'categories' => esc_html__('Categories', 'fliz-video-generator'),
            'has_video' => esc_html__('Fliz Video', 'fliz-video-generator'),
            'date' => esc_html__('Date', 'fliz-video-generator')
        ];
    }

    protected function get_views() {
        $views = [];
        $current = isset($_GET['has_fliz_video']) ? 
            sanitize_text_field(wp_unslash($_GET['has_fliz_video'])) : 
            '';

        $views['all'] = sprintf(
            '<a href="%s"%s>%s</a>',
            remove_query_arg('has_fliz_video'),
            empty($current) ? ' class="current"' : '',
            esc_html__('All', 'fliz-video-generator')
        );

        $views['no_video'] = sprintf(
            '<a href="%s"%s>%s</a>',
            add_query_arg('has_fliz_video', 'no'),
            $current === 'no' ? ' class="current"' : '',
            esc_html__('Without video', 'fliz-video-generator')
        );

        $views['has_video'] = sprintf(
            '<a href="%s"%s>%s</a>',
            add_query_arg('has_fliz_video', 'yes'),
            $current === 'yes' ? ' class="current"' : '',
            esc_html__('With video', 'fliz-video-generator')
        );

        return $views;
    }

    protected function extra_tablenav($which) {
        if ($which !== 'top') return;
        ?>
        <div class="alignleft actions">
            <?php
            wp_dropdown_categories([
                'show_option_all' => esc_html__('All categories', 'fliz-video-generator'),
                'orderby' => 'name',
                'selected' => isset($_REQUEST['cat']) ? absint(wp_unslash($_REQUEST['cat'])) : '',
                'name' => 'cat',
                'hide_empty' => false
            ]);

            wp_dropdown_users([
                'show_option_all' => esc_html__('All authors', 'fliz-video-generator'),
                'name' => 'author',
                'selected' => isset($_REQUEST['author']) ? absint(wp_unslash($_REQUEST['author'])) : ''
            ]);

            $this->months_dropdown('post');

            submit_button(
                esc_html__('Filter', 'fliz-video-generator'),
                '',
                'filter_action',
                false
            );
            ?>
        </div>
        <?php
    }

    public function prepare_items() {
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);

        $per_page = 20;
        $current_page = $this->get_pagenum();

        $args = [
            'post_type' => 'post',
            'posts_per_page' => $per_page,
            'paged' => $current_page,
            'orderby' => isset($_REQUEST['orderby']) ? 
                sanitize_text_field(wp_unslash($_REQUEST['orderby'])) : 
                'date',
            'order' => isset($_REQUEST['order']) ? 
                sanitize_text_field(wp_unslash($_REQUEST['order'])) : 
                'DESC',
            'post_status' => ['publish', 'draft', 'pending']
        ];

        if (isset($_REQUEST['cat'])) {
            $args['cat'] = absint(wp_unslash($_REQUEST['cat']));
        }

        if (isset($_REQUEST['author'])) {
            $args['author'] = absint(wp_unslash($_REQUEST['author']));
        }

        if (isset($_REQUEST['m'])) {
            $args['m'] = sanitize_text_field(wp_unslash($_REQUEST['m']));
        }

        if (isset($_REQUEST['s'])) {
            $args['s'] = sanitize_text_field(wp_unslash($_REQUEST['s']));
        }

        if (isset($_REQUEST['has_fliz_video'])) {
            $has_fliz_video = sanitize_text_field(wp_unslash($_REQUEST['has_fliz_video']));
            $args['meta_query'] = [
                [
                    'key' => '_fliz_video_id',
                    'compare' => $has_fliz_video === 'yes' ? 'EXISTS' : 'NOT EXISTS'
                ]
            ];
        }

        $query = new \WP_Query($args);
        $this->items = $query->posts;
        $total_items = $query->found_posts;

        $this->set_pagination_args([
            'total_items' => $total_items,
            'per_page'    => $per_page,
            'total_pages' => ceil($total_items / $per_page)
        ]);
    }

    protected function column_title($item) {
        $title = empty($item->post_title) ? 
            esc_html__('(no title)', 'fliz-video-generator') : 
            esc_html($item->post_title);
        
        return sprintf(
            '<a href="%s"><strong>%s</strong></a>',
            get_edit_post_link($item->ID),
            $title
        );
    }

    protected function column_author($item) {
        $author = get_user_by('id', $item->post_author);
        return $author ? esc_html($author->display_name) : '';
    }

    protected function column_categories($item) {
        $categories = get_the_category($item->ID);
        $cat_links = [];
        foreach ($categories as $cat) {
            $cat_links[] = sprintf(
                '<a href="%s">%s</a>',
                esc_url(add_query_arg(['cat' => $cat->term_id])),
                esc_html($cat->name)
            );
        }
        return implode(', ', $cat_links);
    }

    protected function column_has_video($item) {
        $video_id = get_post_meta($item->ID, '_fliz_video_id', true);
        if ($video_id) {
            return sprintf(
                '<span class="dashicons dashicons-yes" style="color: #46b450;" title="%s"></span>',
                esc_attr__('Video generated', 'fliz-video-generator')
            );
        }
        return sprintf(
            '<span class="dashicons dashicons-no" style="color: #dc3232;" title="%s"></span>',
            esc_attr__('No video', 'fliz-video-generator')
        );
    }

    protected function column_date($item) {
        return get_the_date('', $item);
    }

    protected function column_cb($item) {
        return sprintf(
            '<input type="checkbox" name="posts[]" value="%s" />',
            $item->ID
        );
    }

    protected function get_sortable_columns() {
        return [
            'title' => ['title', true],
            'author' => ['author', false],
            'date' => ['date', true]
        ];
    }

    public function display() {
        $this->prepare_items();
        ?>
        <div class="wrap">
            <h1><?php echo esc_html__('Generate videos', 'fliz-video-generator'); ?></h1>
            
            <div class="notice notice-info">
                <p><?php echo esc_html__('Select the posts for which you want to generate videos.', 'fliz-video-generator'); ?></p>
            </div>

            <form id="posts-filter" method="get">
                <input type="hidden" name="page" value="fliz-video-bulk">
                
                <?php
                // Bouton Generate videos et filtres sur la même ligne
                echo '<div class="tablenav top">';
                echo '<div class="alignleft actions bulkactions">';
                echo '<button type="button" class="button button-primary" id="generate-video-button">' . 
                     esc_html__('Generate videos', 'fliz-video-generator') . 
                     '</button>';
                echo '</div>';
                
                // Affichage des filtres
                $this->extra_tablenav('top');
                echo '</div>';

                // Affichage des vues (All, With video, Without video)
                $this->views();

                // Affichage de la table
                ?>
                <table class="wp-list-table <?php echo implode(' ', $this->get_table_classes()); ?>">
                    <thead>
                        <tr>
                            <?php $this->print_column_headers(); ?>
                        </tr>
                    </thead>
                    <tbody>
                        <?php $this->display_rows_or_placeholder(); ?>
                    </tbody>
                </table>

                <?php
                // Affichage de la pagination
                $this->display_tablenav('bottom');
                ?>
            </form>
        </div>
        <?php
        
        // Modal de configuration
        $this->render_modal();
    }

    private function render_modal() {
        ?>
        <div id="fliz-generator-modal" class="fliz-modal" style="display: none;">
            <div class="fliz-modal-content">
                <h2><?php echo esc_html__('Generation settings', 'fliz-video-generator'); ?></h2>
                
                <div class="fliz-modal-body">
                    <p>
                        <label><?php echo esc_html__('Video type:', 'fliz-video-generator'); ?></label><br>
                        <select name="video_type" id="fliz-video-type">
                            <option value="article">
                                <?php echo esc_html__('Article', 'fliz-video-generator'); ?>
                            </option>
                            <option value="ad">
                                <?php echo esc_html__('Advertisement', 'fliz-video-generator'); ?>
                            </option>
                            <option value="product">
                                <?php echo esc_html__('Product', 'fliz-video-generator'); ?>
                            </option>
                        </select>
                    </p>

                    <p>
                        <label><?php echo esc_html__('Format:', 'fliz-video-generator'); ?></label><br>
                        <select name="video_format" id="fliz-video-format">
                            <option value="size_16_9">16:9</option>
                            <option value="size_9_16">9:16</option>
                            <option value="square">
                                <?php echo esc_html__('Square', 'fliz-video-generator'); ?>
                            </option>
                        </select>
                    </p>
                </div>

                <div class="fliz-modal-footer">
                    <button type="button" class="button button-secondary fliz-modal-close">
                        <?php echo esc_html__('Cancel', 'fliz-video-generator'); ?>
                    </button>
                    <button type="button" class="button button-primary" id="fliz-generate-videos">
                        <?php echo esc_html__('Generate', 'fliz-video-generator'); ?>
                    </button>
                </div>
            </div>
        </div>
        <?php
    }
} 