<?php
namespace FlizVideoGenerator\Admin;

class Settings {
    public function __construct() {
        add_action('admin_post_save_fliz_api_key', [$this, 'handle_form_submission']);
    }

    public function handle_form_submission() {
        if (!current_user_can('manage_options')) {
            wp_die(
                esc_html__('You do not have sufficient permissions to perform this action.', 'fliz-video-generator')
            );
        }

        if (!isset($_POST['_wpnonce']) || 
            !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['_wpnonce'])), 'save_fliz_api_key')) {
            wp_die(
                esc_html__('Unauthorized action.', 'fliz-video-generator')
            );
        }

        $api_key = isset($_POST['fliz_api_key']) ? 
            sanitize_text_field(wp_unslash($_POST['fliz_api_key'])) : 
            '';

        if (empty($api_key)) {
            set_transient('fliz_api_key_error', 
                esc_html__('API key cannot be empty.', 'fliz-video-generator'), 
                30
            );
            wp_redirect(admin_url('admin.php?page=fliz-video&error=1'));
            exit;
        }

        $api = new \FlizVideoGenerator\Api\FlizApi($api_key);
        $test = $api->test_connection();

        if (is_wp_error($test)) {
            set_transient('fliz_api_key_error', 
                esc_html__('Your API key is invalid', 'fliz-video-generator'), 
                30
            );
            wp_redirect(admin_url('admin.php?page=fliz-video&error=1'));
            exit;
        }

        update_option('fliz_api_key', $api_key);
        set_transient('fliz_api_key_success', 
            esc_html__('API key successfully saved.', 'fliz-video-generator'), 
            30
        );
        wp_redirect(admin_url('admin.php?page=fliz-video&updated=1'));
        exit;
    }

    public function render_settings_page() {
        $error_message = get_transient('fliz_api_key_error');
        $success_message = get_transient('fliz_api_key_success');
        
        if ($error_message) delete_transient('fliz_api_key_error');
        if ($success_message) delete_transient('fliz_api_key_success');
        
        $allowed_html = [
            'a' => [
                'href' => [],
                'target' => []
            ]
        ];

        ob_start();
        ?>
        <div class="wrap">
            <div style="display: flex; align-items: center; margin-bottom: 20px;">
                <?php
                /* translators: Alt text for Fliz logo */
                $logo_alt = esc_attr__('Fliz', 'fliz-video-generator');
                printf(
                    '<img src="%s" alt="%s" style="height: 50px; margin-right: 20px;">',
                    esc_url('https://fliz.ai/wp-content/uploads/2023/07/Logo_Fliz-2.svg'),
                    esc_attr($logo_alt)
                );
                ?>
                <h1><?php echo esc_html__('Fliz API Key Management', 'fliz-video-generator'); ?></h1>
            </div>
            
            <div class="fliz-description" style="background: #fff; padding: 20px; margin-bottom: 20px; border-left: 4px solid #2271b1;">
                <?php
                echo '<p>' . esc_html__('Create videos in 1 click using Fliz AI and insert them directly into your WordPress posts.', 'fliz-video-generator') . '</p>';
                echo '<p>';
                echo wp_kses(
                    sprintf(
                        /* translators: %s: URL */
                        __('Get your API key by signing up on <a href="%s" target="_blank">Fliz.ai</a>', 'fliz-video-generator'),
                        esc_url('https://fliz.ai')
                    ),
                    [
                        'a' => [
                            'href' => [],
                            'target' => []
                        ]
                    ]
                );
                echo '</p>';
                ?>
            </div>
            
            <div class="card" style="max-width: 600px;">
                <h2 class="title"><?php echo esc_html__('API Key', 'fliz-video-generator'); ?></h2>
                
                <form method="post" action="<?php echo esc_url(admin_url('admin-post.php')); ?>">
                    <input type="hidden" name="action" value="save_fliz_api_key">
                    <?php wp_nonce_field('save_fliz_api_key'); ?>
                    
                    <p>
                        <input type="text" 
                               id="fliz_api_key" 
                               name="fliz_api_key" 
                               value="<?php echo esc_attr(get_option('fliz_api_key')); ?>" 
                               class="regular-text" 
                               style="width: 100%;">
                        <?php if ($error_message): ?>
                            <span style="color: #dc3232; font-weight: bold; font-size: 12px; display: block; margin-top: 5px;">
                                <?php echo esc_html($error_message); ?>
                            </span>
                        <?php endif; ?>
                        <?php if ($success_message): ?>
                            <span style="color: #46b450; font-weight: bold; font-size: 12px; display: block; margin-top: 5px;">
                                <?php echo esc_html($success_message); ?>
                            </span>
                        <?php endif; ?>
                    </p>
                    
                    <?php submit_button(esc_html__('Save', 'fliz-video-generator')); ?>
                </form>
            </div>

            <?php
            $api = new \FlizVideoGenerator\Api\FlizApi();
            $credits = $api->get_credits();
            if (!is_wp_error($credits)) {
                printf(
                    '<p class="description" style="margin-top: 20px;">%s</p>',
                    esc_html(
                        sprintf(
                            /* translators: %d: credits number */
                            __('You have %d video credits remaining.', 'fliz-video-generator'),
                            intval($credits)
                        )
                    )
                );
            }
            ?>
        </div>
        <?php
        echo ob_get_clean();
    }
} 