<?php
namespace FlizVideoGenerator\Api;

class FlizApi {
    private $api_key;
    private $endpoint = 'https://api.fliz.ai/v1/graphql';
    private $create_video_query = '
        mutation CreateVideo($input: fliz_video_create_input!) {
            fliz_video_create(fliz_video_create_input: $input) {
                video_id
            }
        }
    ';

    private $get_video_query = '
        query GetVideo($id: uuid!) {
            fliz_video_by_pk(id: $id) {
                url
                step
            }
        }
    ';

    public function __construct($api_key = null) {
        $this->api_key = $api_key ?: get_option('fliz_api_key');
    }

    public function create_video($input) {
        // Formatage des données d'entrée
        $formatted_input = [
            'name' => (string) substr($input['name'], 0, 255),
            'description' => (string) wp_strip_all_tags($input['description']),
            'format' => (string) $input['format'],
            'category' => (string) $input['category'],
            'lang' => (string) substr(get_locale(), 0, 2),
            'site_name' => (string) get_bloginfo('name'),
            'site_url' => (string) get_permalink($input['post_id'])
        ];

        // Nettoyage des valeurs vides
        $formatted_input = array_filter($formatted_input, function($value) {
            return $value !== '' && $value !== null;
        });

        return $this->graphql_request($this->create_video_query, ['input' => $formatted_input]);
    }

    public function get_video_status($video_id) {
        $result = $this->graphql_request($this->get_video_query, ['id' => $video_id]);
        
        if (is_wp_error($result)) {
            return $result;
        }

        // Vérification et transformation de la réponse
        if (isset($result['fliz_video_by_pk'])) {
            return [
                'url' => $result['fliz_video_by_pk']['url'] ?? null,
                'step' => $result['fliz_video_by_pk']['step'] ?? null
            ];
        }

        return new \WP_Error('api_error', __('Video not found', 'fliz-video-generator'));
    }

    public function test_connection() {
        // Requête GraphQL simple pour tester la connexion
        $query = '{__typename}';

        $response = wp_remote_post($this->endpoint, [
            'headers' => [
                'Content-Type' => 'application/json',
                'Authorization' => 'Bearer ' . trim($this->api_key)
            ],
            'body' => wp_json_encode(['query' => $query]),
            'timeout' => 30
        ]);

        if (is_wp_error($response)) {
            return new \WP_Error('fliz_api_error', 'Erreur de connexion: ' . $response->get_error_message());
        }

        $body = json_decode(wp_remote_retrieve_body($response), true);

        if (json_last_error() !== JSON_ERROR_NONE) {
            return new \WP_Error('fliz_api_error', 'Erreur de décodage JSON: ' . json_last_error_msg());
        }

        if (isset($body['errors'])) {
            $error_message = implode(', ', array_column($body['errors'], 'message'));
            return new \WP_Error('fliz_api_error', 'Erreur API: ' . $error_message);
        }

        if (!isset($body['data']['__typename'])) {
            return new \WP_Error('fliz_api_error', 'Réponse invalide de l\'API');
        }

        return true;
    }

    public function get_credits() {
        $query = 'query { fliz_app_subscription { monthly_credits lifetime_credits } }';

        $response = wp_remote_post($this->endpoint, [
            'headers' => [
                'Content-Type' => 'application/json',
                'Authorization' => 'Bearer ' . $this->api_key
            ],
            'body' => wp_json_encode(['query' => $query]),
            'timeout' => 30
        ]);

        if (is_wp_error($response)) {
            return new \WP_Error('fliz_api_error', 'Erreur de connexion: ' . $response->get_error_message());
        }

        $body = json_decode(wp_remote_retrieve_body($response), true);

        if (json_last_error() !== JSON_ERROR_NONE) {
            return new \WP_Error('fliz_api_error', 'Erreur de décodage JSON: ' . json_last_error_msg());
        }

        if (isset($body['errors'])) {
            $error_message = implode(', ', array_column($body['errors'], 'message'));
            return new \WP_Error('fliz_api_error', 'Erreur API: ' . $error_message);
        }

        $credits = 0;
        if (isset($body['data']['fliz_app_subscription'][0])) {
            $subscription = $body['data']['fliz_app_subscription'][0];
            $credits = $subscription['monthly_credits'] + $subscription['lifetime_credits'];
        }

        return $credits;
    }

    private function graphql_request($query, $variables) {
        if (empty($this->api_key)) {
            return new \WP_Error(
                'no_api_key',
                esc_html__('No API key has been configured. Please configure your API key in the plugin settings.', 'fliz-video-generator')
            );
        }

        $response = wp_remote_post($this->endpoint, [
            'headers' => [
                'Content-Type' => 'application/json',
                'Authorization' => 'Bearer ' . trim($this->api_key)
            ],
            'body' => wp_json_encode([
                'query' => $query,
                'variables' => $variables
            ]),
            'timeout' => 15
        ]);

        if (is_wp_error($response)) {
            error_log('WP Error: ' . $response->get_error_message());
            return $response;
        }

        $status_code = wp_remote_retrieve_response_code($response);
        $body = wp_remote_retrieve_body($response);
        
        error_log('API Response Status: ' . $status_code);
        error_log('API Response Body: ' . $body);

        if ($status_code !== 200) {
            return new \WP_Error(
                'api_error',
                sprintf(
                    esc_html__('HTTP Error %1$d: %2$s', 'fliz-video-generator'),
                    $status_code,
                    wp_remote_retrieve_response_message($response)
                )
            );
        }

        $decoded_body = json_decode($body, true);

        if (json_last_error() !== JSON_ERROR_NONE) {
            return new \WP_Error(
                'api_error',
                esc_html__('Invalid JSON response from API', 'fliz-video-generator')
            );
        }

        if (isset($decoded_body['errors'])) {
            $error_message = isset($decoded_body['errors'][0]['message']) ? 
                $decoded_body['errors'][0]['message'] : 
                esc_html__('Unknown GraphQL error', 'fliz-video-generator');
            
            return new \WP_Error('api_error', $error_message);
        }

        return $decoded_body['data'] ?? null;
    }

    public function ajax_check_video_status() {
        check_ajax_referer('fliz_video_nonce', 'nonce');

        if (!isset($_POST['video_id'])) {
            wp_send_json_error(__('Video ID is required', 'fliz-video-generator'));
        }

        $video_id = sanitize_text_field(wp_unslash($_POST['video_id']));
        $result = $this->get_video_status($video_id);

        if (is_wp_error($result)) {
            wp_send_json_error($result->get_error_message());
        }

        // Vérification de l'URL de la vidéo
        if (!isset($result['url']) || empty($result['url'])) {
            wp_send_json_error(__('Video URL not found.', 'fliz-video-generator'));
        }

        wp_send_json_success([
            'url' => $result['url'],
            'step' => $result['step'] ?? null
        ]);
    }
} 