<?php
namespace FlizVideoGenerator\AutoGenerator;

class VideoGenerator {
    private $api;

    public function __construct() {
        $this->api = new \FlizVideoGenerator\Api\FlizApi();
        add_action('init', [$this, 'schedule_generation']);
        add_action('fliz_generate_videos', [$this, 'generate_videos']);
    }

    public function schedule_generation() {
        if (!wp_next_scheduled('fliz_generate_videos')) {
            wp_schedule_event(time(), 'hourly', 'fliz_generate_videos');
        }
    }

    public function generate_videos() {
        // Vérifier les crédits disponibles
        $credits = $this->api->get_credits();
        if (is_wp_error($credits) || $credits <= 0) {
            return;
        }

        // Récupérer les articles sans vidéo
        $posts = $this->get_posts_without_video(min($credits, 10));
        if (empty($posts)) {
            return;
        }

        foreach ($posts as $post) {
            $input = [
                'post_id' => $post->ID,
                'name' => $post->post_title,
                'description' => wp_strip_all_tags($post->post_content),
                'site_url' => get_permalink($post->ID),
                'site_name' => get_bloginfo('name'),
                'lang' => substr(get_locale(), 0, 2),
                'format' => 'size_16_9',
                'category' => 'article'
            ];

            $result = $this->api->create_video($input);
            if (!is_wp_error($result) && isset($result['fliz_video_create']['video_id'])) {
                $video_id = $result['fliz_video_create']['video_id'];
                update_post_meta($post->ID, '_fliz_video_id', $video_id);

                // Ajouter le shortcode à la fin de l'article
                $content = $post->post_content;
                if (substr($content, -1) !== "\n") {
                    $content .= "\n";
                }
                $content .= sprintf('[fliz_video id="%s"]', esc_attr($video_id));

                wp_update_post([
                    'ID' => $post->ID,
                    'post_content' => $content
                ]);
            }
        }
    }

    private function get_posts_without_video($limit = 10) {
        // Utiliser WP_Query au lieu d'une requête directe
        $args = [
            'post_type' => 'post',
            'post_status' => 'publish',
            'posts_per_page' => absint($limit),
            'meta_query' => [
                [
                    'key' => '_fliz_video_id',
                    'compare' => 'NOT EXISTS'
                ]
            ],
            'orderby' => 'date',
            'order' => 'DESC',
            'cache_results' => true,
            'update_post_meta_cache' => true,
            'update_post_term_cache' => false
        ];

        $query = new \WP_Query($args);
        
        // Mettre en cache les résultats
        wp_cache_set(
            'fliz_posts_without_video_' . $limit,
            $query->posts,
            'fliz_video_generator',
            HOUR_IN_SECONDS
        );

        return $query->posts;
    }

    private function get_post_video_status($post_id) {
        $cache_key = 'fliz_video_status_' . $post_id;
        $status = wp_cache_get($cache_key, 'fliz_video_generator');

        if (false === $status) {
            $video_id = get_post_meta($post_id, '_fliz_video_id', true);
            if (!$video_id) {
                return false;
            }

            $result = $this->api->get_video_status($video_id);
            if (is_wp_error($result)) {
                return false;
            }

            $status = isset($result['fliz_video_by_pk']['status']) ? $result['fliz_video_by_pk']['status'] : false;
            wp_cache_set($cache_key, $status, 'fliz_video_generator', MINUTE_IN_SECONDS);
        }

        return $status;
    }
} 